##############################################################################
# $Id: profiles.pl,v 1.2 1999/08/26 04:06:57 jheiss Exp $
##############################################################################
# Define paths to various files needed by the Jumpstart scripts.
#
# This file contains the largest bunch of nested Perl data structures you are
# ever likely to encounter.  Have your Perl book ready.  :)
#
# For each image you need to define entries in the following hashes:
# 1)  %ARCHS
#     Architectures (like sun4m or sun4u) which this image works on.
# 2)  %CD_IMAGE
# 3)  %PROFILE
#     Paths to CD-ROM images and profile directories on install/profile
#     servers.  These are used to define the install= and install_config=
#     entries in the  bootparams map.  The CD_IMAGE hash is also used as a
#     base directory by other definitions in this file.
# 4)  %BOOT_IMAGE_BASE
#     The base of the boot image directory structure.
# 5)  %BOOT_IMAGE
#     Paths to the boot image on the boot servers.  This is used for the root=
#     entry in the bootparams map.
# 6)  %INETBOOT
#     Path to inetboot kernels.  Config refers to these paths when setting up
#     the boot server for a machine.  Note that these paths only need to exist,
#     etc. on the Jumpstart master because the files are copied from there to
#     the boot server.  The inetboot kernel is the file the machine gets via
#     tftp as the second step in booting via the network, right after doing a
#     rarp to get it's IP address.
# 7)  %TFTPFILE
#     Name of inetboot kernels in /tftpboot directory.  The inetboot files
#     defined above are copied to /tftpboot on the boot servers with the names
#     defined here.  Symlinks for each machine are then made to these files.
#
# The nesting for each of these hashes work like this:
#    $HASH{image}->{image version}->{subimage}->{architecture}
# Note that the ARCHS hash is missing the architecture level for obvious
# reasons.  For images that don't have any subimages (probably most of them)
# just put 'default' in the subimage level.
#
# So $CD_IMAGE{client}->{'1.7'}->{default}->{sun4m} would define the path to
# the CD-ROM image for the sun4u architecture on the 1.7 standard client.
# The quotes around 1.7 aren't necessary but for 2.0 they are because Perl
# wants to interpret 2.0 as a number and just make it 2.  Perl also doesn't
# seem to like things like 1.0beta without quotes.  So I just make a habit of
# putting quotes around the version numbers.
#
# NOTE:  You should run 'perl -c profiles.pl' after editing this file to make
#        sure you haven't mistyped anything.
##############################################################################
# Copyright (C) 1999  Jason Heiss (jheiss@ofb.net)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
##############################################################################
# Pre-RCS version control:
# created 09/29/97
# last modified 05/04/98
##############################################################################
# $Log: profiles.pl,v $
# Revision 1.2  1999/08/26 04:06:57  jheiss
# Added copyright and GNU license message.
#
# Revision 1.1  1999/08/09 03:09:22  jheiss
# Initial revision
#
##############################################################################

require 'basedir.pl';
#use strict;

#############
# Constants #
#############
$BADIMAGE = 100;
$BADVERSION = 200;
$BADSUBIMAGE = 300;

###############
# Subroutines #
###############

sub check_profile
{
	my ($image, $image_version, $subimage) = @_;

	unless (defined($image) && defined($image_version) && defined($subimage))
	{
		die "Invalid arguments to \&check_profile";
	}

	return $BADIMAGE unless (defined($PROFILE{$image}));
	return $BADVERSION unless (defined($PROFILE{$image}->{$image_version}));
	return $BADSUBIMAGE
		unless (defined($PROFILE{$image}->{$image_version}->{$subimage}));
}

sub profile_lookup
{
	my ($rhash, $image, $image_version, $subimage, $arch) = @_;

	unless (defined($rhash) &&
			defined($image) &&
			defined($image_version) &&
			defined($subimage) &&
			defined($arch))
	{
		die "Invalid arguments to \&profile_lookup";
	}

	if (defined($rhash->{$image}->{$image_version}->{$subimage}))
	{
		return $rhash->{$image}->{$image_version}->{$subimage}->{$arch};
	}
	else
	{
		return $rhash->{$image}->{$image_version}->{default}->{$arch};
	}
}

sub check_install_server
{
	my ($install_server, $image, $image_version, $subimage, $arch) = @_;

	unless (defined($install_server) &&
			defined($image) &&
			defined($image_version) &&
			defined($subimage) &&
			defined($arch))
	{
		die "Invalid arguments to \&check_install_server";
	}

	#print "check_install_server called for $install_server\n";
	#print "$image, $image_version, $subimage, $arch\n";

	# We need to check if the boot, cd and profile directories exist
	unless (rsh_file_exists($install_server,
							profile_lookup(\%BOOT_IMAGE,
											$image,
											$image_version,
											$subimage,
											$arch)))
	{
		#print "No boot image on $install_server\n";
		return -1;
	}

	unless (rsh_file_exists($install_server,
							profile_lookup(\%CD_IMAGE,
											$image,
											$image_version,
											$subimage,
											$arch)))
	{
		#print "No CD image on $install_server\n";
		return -2;
	}

	unless (rsh_file_exists($install_server,
							profile_lookup(\%PROFILE,
											$image,
											$image_version,
											$subimage,
											$arch)))
	{
		#print "No profile directory on $install_server\n";
		return -3;
	}

	# Got here so things must be ok...
	return 0;
}

# Return an array listing all of the images
sub all_images
{
	return sort keys %PROFILE;
}

sub print_all_images
{
	my $image;
	foreach $image (all_images())
	{
		print "$image\n";
	}
}

# Return an array listing all versions for a given image
sub all_versions
{
	my $image = $_[0];

	die "Invalid arguments to \&all_versions" unless (defined($image));

	return sort keys %{$PROFILE{$image}};
}

sub print_all_versions
{
	die "Invalid arguments to \&print_all_versions" unless (defined($_[0]));

	my $version;
	foreach $version (all_versions(@_))
	{
		print "$version\n";
	}
}

sub all_subimages
{
	my ($image, $image_version) = @_;

	unless (defined($image) && defined($image_version))
	{
		die "Invalid arguments to \&all_subimages";
	}

	return sort keys %{$PROFILE{$image}->{$image_version}};
}

sub print_all_subimages
{
	die "Invalid arguments to \&print_all_subimages"
		unless (defined($_[0]) && defined($_[1]));

	my $subimage;
	foreach $subimage (all_subimages(@_))
	{
		print "$subimage\n";
	}
}

#######################
# Standard client 1.7 #
#######################
$ARCHS{client}->{'1.7'}->{default} = ['sun4m', 'sun4u'];
$CD_IMAGE{client}->{'1.7'}->{default}->{sun4m} =
	'/export/install/Solaris_2.4';
$CD_IMAGE{client}->{'1.7'}->{default}->{sun4u} =
	'/export/install/Solaris_2.5.1';
$PROFILE{client}->{'1.7'}->{default}->{sun4m} =
	'/export/install/jumpstart/5.4';
$PROFILE{client}->{'1.7'}->{default}->{sun4u} =
	'/export/install/jumpstart/5.5.1';
$BOOT_IMAGE_BASE{client}->{'1.7'}->{default}->{sun4m} =
	'/export/install/media/5.4';
$BOOT_IMAGE{client}->{'1.7'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{client}->{'1.7'}->{default}->{sun4m} .
	'/export/exec/kvm/sparc.sun4m.Solaris_2.4';
$BOOT_IMAGE_BASE{client}->{'1.7'}->{default}->{sun4u} =
	'/export/install/media/5.5.1';
$BOOT_IMAGE{client}->{'1.7'}->{default}->{sun4u} =
	$BOOT_IMAGE_BASE{client}->{'1.7'}->{default}->{sun4u} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$INETBOOT{client}->{'1.7'}->{default}->{sun4m} =
	$CD_IMAGE{client}->{'1.7'}->{default}->{sun4m} .
	'/export/exec/sparc.Solaris_2.4/lib/fs/nfs/inetboot';
$INETBOOT{client}->{'1.7'}->{default}->{sun4u} =
	$CD_IMAGE{client}->{'1.7'}->{default}->{sun4u} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4u/lib/fs/nfs/inetboot';
$TFTPFILE{client}->{'1.7'}->{default}->{sun4m} = 'inetboot.SUN4M.Solaris_2.4';
$TFTPFILE{client}->{'1.7'}->{default}->{sun4u} = 'inetboot.SUN4U.Solaris_2.5.1';

#######################
# Standard client 2.0 #
#######################
$ARCHS{client}->{'2.0'}->{default} = ['sun4m', 'sun4u'];
$CD_IMAGE{client}->{'2.0'}->{default}->{sun4m} =
	'/export/install/Solaris_2.5.1';
$CD_IMAGE{client}->{'2.0'}->{default}->{sun4u} =
	'/export/install/Solaris_2.5.1';
$PROFILE{client}->{'2.0'}->{js}->{sun4m} =
	'/export/install/jumpstart/Client/2.0/js';
$PROFILE{client}->{'2.0'}->{js}->{sun4u} =
	'/export/install/jumpstart/Client/2.0/js';
$PROFILE{client}->{'2.0'}->{qj}->{sun4m} =
	'/export/install/jumpstart/Client/2.0/qj';
$PROFILE{client}->{'2.0'}->{qj}->{sun4u} =
	'/export/install/jumpstart/Client/2.0/qj';
$PROFILE{client}->{'2.0'}->{qjd}->{sun4m} =
	'/export/install/jumpstart/Client/2.0/qjd';
$PROFILE{client}->{'2.0'}->{qjd}->{sun4u} =
	'/export/install/jumpstart/Client/2.0/qjd';
$BOOT_IMAGE_BASE{client}->{'2.0'}->{default}->{sun4m} =
	'/export/install/Solaris_2.5.1';
$BOOT_IMAGE{client}->{'2.0'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{client}->{'2.0'}->{default}->{sun4m} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$BOOT_IMAGE_BASE{client}->{'2.0'}->{default}->{sun4u} =
	'/export/install/Solaris_2.5.1';
$BOOT_IMAGE{client}->{'2.0'}->{default}->{sun4u} =
	$BOOT_IMAGE_BASE{client}->{'2.0'}->{default}->{sun4u} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$INETBOOT{client}->{'2.0'}->{default}->{sun4m} =
	$CD_IMAGE{client}->{'2.0'}->{default}->{sun4m} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4m/lib/fs/nfs/inetboot';
$INETBOOT{client}->{'2.0'}->{default}->{sun4u} =
	$CD_IMAGE{client}->{'2.0'}->{default}->{sun4u} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4u/lib/fs/nfs/inetboot';
$TFTPFILE{client}->{'2.0'}->{default}->{sun4m} = 'inetboot.SUN4M.Solaris_2.5.1';
$TFTPFILE{client}->{'2.0'}->{default}->{sun4u} = 'inetboot.SUN4U.Solaris_2.5.1';

#######################
# Standard client 2.1 #
#######################
$ARCHS{client}->{'2.1'}->{default} = ['sun4m', 'sun4u'];
$CD_IMAGE{client}->{'2.1'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.5.1_1197';
$CD_IMAGE{client}->{'2.1'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.5.1_1197';
$PROFILE{client}->{'2.1'}->{js}->{sun4m} =
	'/export/install/Profiles/stdclient/2.1/js';
$PROFILE{client}->{'2.1'}->{js}->{sun4u} =
	'/export/install/Profiles/stdclient/2.1/js';
$PROFILE{client}->{'2.1'}->{qj}->{sun4m} =
	'/export/install/Profiles/stdclient/2.1/qj';
$PROFILE{client}->{'2.1'}->{qj}->{sun4u} =
	'/export/install/Profiles/stdclient/2.1/qj';
$PROFILE{client}->{'2.1'}->{cqjd}->{sun4m} =
	'/export/install/Profiles/stdclient/2.1/cqjd';
$PROFILE{client}->{'2.1'}->{cqjd}->{sun4u} =
	'/export/install/Profiles/stdclient/2.1/cqjd';
$BOOT_IMAGE_BASE{client}->{'2.1'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.5.1_1197';
$BOOT_IMAGE{client}->{'2.1'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{client}->{'2.1'}->{default}->{sun4m} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$BOOT_IMAGE_BASE{client}->{'2.1'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.5.1_1197';
$BOOT_IMAGE{client}->{'2.1'}->{default}->{sun4u} =
	$BOOT_IMAGE_BASE{client}->{'2.1'}->{default}->{sun4u} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$INETBOOT{client}->{'2.1'}->{default}->{sun4m} =
	$CD_IMAGE{client}->{'2.1'}->{default}->{sun4m} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4m/lib/fs/nfs/inetboot';
$INETBOOT{client}->{'2.1'}->{default}->{sun4u} =
	$CD_IMAGE{client}->{'2.1'}->{default}->{sun4u} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4u/lib/fs/nfs/inetboot';
$TFTPFILE{client}->{'2.1'}->{default}->{sun4m} =
	'inetboot.SUN4M.Solaris_2.5.1_1197';
$TFTPFILE{client}->{'2.1'}->{default}->{sun4u} =
	'inetboot.SUN4U.Solaris_2.5.1_1197';

#######################
# Standard client 2.2 #
#######################
$ARCHS{client}->{'2.2'}->{default} = ['sun4m', 'sun4u'];
$CD_IMAGE{client}->{'2.2'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.5.1_1197';
$CD_IMAGE{client}->{'2.2'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.5.1_1197';
$PROFILE{client}->{'2.2'}->{js}->{sun4m} =
	'/export/install/Profiles/stdclient/2.2/js';
$PROFILE{client}->{'2.2'}->{js}->{sun4u} =
	'/export/install/Profiles/stdclient/2.2/js';
$PROFILE{client}->{'2.2'}->{qj}->{sun4m} =
	'/export/install/Profiles/stdclient/2.2/qj';
$PROFILE{client}->{'2.2'}->{qj}->{sun4u} =
	'/export/install/Profiles/stdclient/2.2/qj';
$BOOT_IMAGE_BASE{client}->{'2.2'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.5.1_1197';
$BOOT_IMAGE{client}->{'2.2'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{client}->{'2.2'}->{default}->{sun4m} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$BOOT_IMAGE_BASE{client}->{'2.2'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.5.1_1197';
$BOOT_IMAGE{client}->{'2.2'}->{default}->{sun4u} =
	$BOOT_IMAGE_BASE{client}->{'2.2'}->{default}->{sun4u} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$INETBOOT{client}->{'2.2'}->{default}->{sun4m} =
	$CD_IMAGE{client}->{'2.2'}->{default}->{sun4m} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4m/lib/fs/nfs/inetboot';
$INETBOOT{client}->{'2.2'}->{default}->{sun4u} =
	$CD_IMAGE{client}->{'2.2'}->{default}->{sun4u} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4u/lib/fs/nfs/inetboot';
$TFTPFILE{client}->{'2.2'}->{default}->{sun4m} =
	'inetboot.SUN4M.Solaris_2.5.1_1197';
$TFTPFILE{client}->{'2.2'}->{default}->{sun4u} =
	'inetboot.SUN4U.Solaris_2.5.1_1197';

#######################
# Standard client 3.0 #
#######################
$ARCHS{client}->{'3.0'}->{default} = ['sun4m', 'sun4u'];
$CD_IMAGE{client}->{'3.0'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.6_0398';
$CD_IMAGE{client}->{'3.0'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.6_0398';
$PROFILE{client}->{'3.0'}->{js}->{sun4m} =
	'/export/install/Profiles/stdclient/3.0/js';
$PROFILE{client}->{'3.0'}->{js}->{sun4u} =
	'/export/install/Profiles/stdclient/3.0/js';
$PROFILE{client}->{'3.0'}->{qj}->{sun4m} =
	'/export/install/Profiles/stdclient/3.0/qj';
$PROFILE{client}->{'3.0'}->{qj}->{sun4u} =
	'/export/install/Profiles/stdclient/3.0/qj';
$BOOT_IMAGE_BASE{client}->{'3.0'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.6_0398';
$BOOT_IMAGE{client}->{'3.0'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{client}->{'3.0'}->{default}->{sun4m} .
	'/Solaris_2.6/Tools/Boot';
$BOOT_IMAGE_BASE{client}->{'3.0'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.6_0398';
$BOOT_IMAGE{client}->{'3.0'}->{default}->{sun4u} =
	$BOOT_IMAGE_BASE{client}->{'3.0'}->{default}->{sun4u} .
	'/Solaris_2.6/Tools/Boot';
$INETBOOT{client}->{'3.0'}->{default}->{sun4m} =
	$CD_IMAGE{client}->{'3.0'}->{default}->{sun4m} .
	'/Solaris_2.6/Tools/Boot/usr/platform/sun4m/lib/fs/nfs/inetboot';
$INETBOOT{client}->{'3.0'}->{default}->{sun4u} =
	$CD_IMAGE{client}->{'3.0'}->{default}->{sun4u} .
	'/Solaris_2.6/Tools/Boot/usr/platform/sun4u/lib/fs/nfs/inetboot';
$TFTPFILE{client}->{'3.0'}->{default}->{sun4m} =
	'inetboot.SUN4M.Solaris_2.6_0398';
$TFTPFILE{client}->{'3.0'}->{default}->{sun4u} =
	'inetboot.SUN4U.Solaris_2.6_0398';

######################
# Network Server 1.0 #
######################
#$ARCHS{netsvr}->{'1.0'}->{default} = ['sun4m', 'sun4u'];
$ARCHS{netsvr}->{'1.0'}->{default} = ['sun4m'];
$CD_IMAGE{netsvr}->{'1.0'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.6_0897';
$CD_IMAGE{netsvr}->{'1.0'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.6_0897';
$PROFILE{netsvr}->{'1.0'}->{default}->{sun4m} =
	'/export/install/Profiles/NetSvr/1.0';
$PROFILE{netsvr}->{'1.0'}->{default}->{sun4u} =
	'/export/install/Profiles/NetSvr/1.0';
$BOOT_IMAGE_BASE{netsvr}->{'1.0'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.6_0897';
$BOOT_IMAGE{netsvr}->{'1.0'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{netsvr}->{'1.0'}->{default}->{sun4m} .
	'/Solaris_2.6/Tools/Boot';
$BOOT_IMAGE_BASE{netsvr}->{'1.0'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.6_0897';
$BOOT_IMAGE{netsvr}->{'1.0'}->{default}->{sun4u} =
	$BOOT_IMAGE_BASE{netsvr}->{'1.0'}->{default}->{sun4u} .
	'/Solaris_2.6/Tools/Boot';
$INETBOOT{netsvr}->{'1.0'}->{default}->{sun4m} =
	$CD_IMAGE{netsvr}->{'1.0'}->{default}->{sun4m} .
	'/Solaris_2.6/Tools/Boot/usr/platform/sun4m/lib/fs/nfs/inetboot';
$INETBOOT{netsvr}->{'1.0'}->{default}->{sun4u} =
	$CD_IMAGE{netsvr}->{'1.0'}->{default}->{sun4u} .
	'/Solaris_2.6/Tools/Boot/usr/platform/sun4u/lib/fs/nfs/inetboot';
$TFTPFILE{netsvr}->{'1.0'}->{default}->{sun4m} =
	'inetboot.SUN4M.Solaris_2.6_0897';
$TFTPFILE{netsvr}->{'1.0'}->{default}->{sun4u} =
	'inetboot.SUN4U.Solaris_2.6_0897';

##########################
# Application Server 1.6 #
##########################
$ARCHS{appserver}->{'1.6'}->{default} = ['sun4m'];
$CD_IMAGE{appserver}->{'1.6'}->{default}->{sun4m} =
	'/export/install/Solaris_2.5';
$PROFILE{appserver}->{'1.6'}->{default}->{sun4m} =
	'/export/install/jumpstart/AppSvr';
$BOOT_IMAGE_BASE{appserver}->{'1.6'}->{default}->{sun4m} =
	$CD_IMAGE{appserver}->{'1.6'}->{default}->{sun4m};
$BOOT_IMAGE{appserver}->{'1.6'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{appserver}->{'1.6'}->{default}->{sun4m} .
	'/export/exec/kvm/sparc.Solaris_2.5';
$INETBOOT{appserver}->{'1.6'}->{default}->{sun4m} =
	$CD_IMAGE{appserver}->{'1.6'}->{default}->{sun4m} .
	'/export/exec/sparc.Solaris_2.5/platform/sun4m/lib/fs/nfs/inetboot';
$TFTPFILE{appserver}->{'1.6'}->{default}->{sun4m} =
	'inetboot.SUN4M.Solaris_2.5';

####################
# Print Server 1.2 #
####################
$ARCHS{printserver}->{'1.2'}->{default} = ['sun4m'];
$CD_IMAGE{printserver}->{'1.2'}->{default}->{sun4m} =
	'/export/install/Solaris_2.5.1';
$PROFILE{printserver}->{'1.2'}->{default}->{sun4m} =
	'/export/install/jumpstart/PrntSvr/1.2';
$BOOT_IMAGE_BASE{printserver}->{'1.2'}->{default}->{sun4m} =
	$CD_IMAGE{printserver}->{'1.2'}->{default}->{sun4m};
$BOOT_IMAGE{printserver}->{'1.2'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{printserver}->{'1.2'}->{default}->{sun4m} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$INETBOOT{printserver}->{'1.2'}->{default}->{sun4m} =
	$CD_IMAGE{printserver}->{'1.2'}->{default}->{sun4m} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4m/lib/fs/nfs/inetboot';
$TFTPFILE{printserver}->{'1.2'}->{default}->{sun4m} =
	'inetboot.SUN4M.Solaris_2.5.1';

#####################
# Backup Server 1.0 #
#####################
$ARCHS{backupsvr}->{'1.0'}->{default} = ['sun4m', 'sun4u'];
$CD_IMAGE{backupsvr}->{'1.0'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.5.1_0596';
$CD_IMAGE{backupsvr}->{'1.0'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.5.1_0596';
$PROFILE{backupsvr}->{'1.0'}->{js}->{sun4m} =
	'/export/install/Profiles/backupsvr/1.0/js';
$PROFILE{backupsvr}->{'1.0'}->{js}->{sun4u} =
	'/export/install/Profiles/backupsvr/1.0/js';
$PROFILE{backupsvr}->{'1.0'}->{qj}->{sun4m} =
	'/export/install/Profiles/backupsvr/1.0/qj';
$PROFILE{backupsvr}->{'1.0'}->{qj}->{sun4u} =
	'/export/install/Profiles/backupsvr/1.0/qj';
$BOOT_IMAGE_BASE{backupsvr}->{'1.0'}->{default}->{sun4m} =
	'/export/install/OS_Images/Solaris_2.5.1_0596';
$BOOT_IMAGE{backupsvr}->{'1.0'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{backupsvr}->{'1.0'}->{default}->{sun4m} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$BOOT_IMAGE_BASE{backupsvr}->{'1.0'}->{default}->{sun4u} =
	'/export/install/OS_Images/Solaris_2.5.1_0596';
$BOOT_IMAGE{backupsvr}->{'1.0'}->{default}->{sun4u} =
	$BOOT_IMAGE_BASE{backupsvr}->{'1.0'}->{default}->{sun4u} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$INETBOOT{backupsvr}->{'1.0'}->{default}->{sun4m} =
	$CD_IMAGE{backupsvr}->{'1.0'}->{default}->{sun4m} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4m/lib/fs/nfs/inetboot';
$INETBOOT{backupsvr}->{'1.0'}->{default}->{sun4u} =
	$CD_IMAGE{backupsvr}->{'1.0'}->{default}->{sun4u} .
	'/export/exec/sparc.Solaris_2.5.1/platform/sun4u/lib/fs/nfs/inetboot';
$TFTPFILE{backupsvr}->{'1.0'}->{default}->{sun4m} =
	'inetboot.SUN4M.Solaris_2.5.1_0596';
$TFTPFILE{backupsvr}->{'1.0'}->{default}->{sun4u} =
	'inetboot.SUN4U.Solaris_2.5.1_0596';

######################
# UltraPenguin 1.0.9 #
######################
$ARCHS{ultrapenguin}->{'1.0.9'}->{default} = ['sun4m', 'sun4u'];
$CD_IMAGE{ultrapenguin}->{'1.0.9'}->{default}->{sun4m} =
	'/export/install/OS_Images/UltraPenguin_1.0.9';
$CD_IMAGE{ultrapenguin}->{'1.0.9'}->{default}->{sun4u} =
	'/export/install/OS_Images/UltraPenguin_1.0.9';
$PROFILE{ultrapenguin}->{'1.0.9'}->{default}->{sun4m} =
	'/export/install/Profiles/stdclient/2.1/js';
$PROFILE{ultrapenguin}->{'1.0.9'}->{default}->{sun4u} =
	'/export/install/Profiles/stdclient/2.1/js';
$BOOT_IMAGE_BASE{ultrapenguin}->{'1.0.9'}->{default}->{sun4m} =
	'/export/install/OS_Images/UltraPenguin_1.0.9';
$BOOT_IMAGE{ultrapenguin}->{'1.0.9'}->{default}->{sun4m} =
	$BOOT_IMAGE_BASE{ultrapenguin}->{'1.0.9'}->{default}->{sun4m} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$BOOT_IMAGE_BASE{ultrapenguin}->{'1.0.9'}->{default}->{sun4u} =
	'/export/install/OS_Images/UltraPenguin_1.0.9';
$BOOT_IMAGE{ultrapenguin}->{'1.0.9'}->{default}->{sun4u} =
	$BOOT_IMAGE_BASE{ultrapenguin}->{'1.0.9'}->{default}->{sun4u} .
	'/export/exec/kvm/sparc.Solaris_2.5.1';
$INETBOOT{ultrapenguin}->{'1.0.9'}->{default}->{sun4m} =
	$CD_IMAGE{ultrapenguin}->{'1.0.9'}->{default}->{sun4m} .
	'/sparc/images/tftpboot.img';
$INETBOOT{ultrapenguin}->{'1.0.9'}->{default}->{sun4u} =
	$CD_IMAGE{ultrapenguin}->{'1.0.9'}->{default}->{sun4u} .
	'/sparc/images/tftpboot.img';
$TFTPFILE{ultrapenguin}->{'1.0.9'}->{default}->{sun4m} =
	'tftpboot.UltraPenguin-1.0.9';
$TFTPFILE{ultrapenguin}->{'1.0.9'}->{default}->{sun4u} =
	'tftpboot.UltraPenguin-1.0.9';

return 1;

